Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(542)

Unified Diff: ash/common/system/tray/system_tray.h

Issue 2190773002: Fix Volume slider is captured in screenshot done in touchview mode (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: several updates included Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/system/tray/system_tray.h
diff --git a/ash/common/system/tray/system_tray.h b/ash/common/system/tray/system_tray.h
index 9029cb16f70f1bdc8e728bd069cfb97fd7b382cf..a8bc7996c0e2848c0773cff4391e8e0b5e9cb3ec 100644
--- a/ash/common/system/tray/system_tray.h
+++ b/ash/common/system/tray/system_tray.h
@@ -25,6 +25,7 @@ class SystemBubbleWrapper;
class SystemTrayDelegate;
class SystemTrayItem;
class TrayAccessibility;
+class TrayAudio;
class TrayCast;
class TrayDate;
class TrayUpdate;
@@ -74,8 +75,9 @@ class ASH_EXPORT SystemTray : public TrayBackgroundView,
// seconds.
void SetDetailedViewCloseDelay(int close_delay);
- // Hides the detailed view for |item|.
- void HideDetailedView(SystemTrayItem* item);
+ // Hides the detailed view for |item|. If |animate| is false, disable
+ // the hiding animation for hiding |item|.
+ void HideDetailedView(SystemTrayItem* item, bool animate);
// Shows the notification view for |item|.
void ShowNotificationView(SystemTrayItem* item);
@@ -121,6 +123,9 @@ class ASH_EXPORT SystemTray : public TrayBackgroundView,
// otherwise.
views::View* GetHelpButtonView() const;
+ // Accessor for tray audio, can be null if !defined(OS_CHROMEOS).
Daniel Erat 2016/08/01 21:10:06 nit: i wouldn't mention the ifdef here, since it m
Qiang(Joe) Xu 2016/08/01 22:56:47 Done.
+ TrayAudio* GetTrayAudio() const;
+
// Accessors for testing.
// Returns true if the bubble exists.
@@ -248,6 +253,7 @@ class ASH_EXPORT SystemTray : public TrayBackgroundView,
bool full_system_tray_menu_;
TrayAccessibility* tray_accessibility_; // not owned
Daniel Erat 2016/08/01 21:10:06 nit: if none of these are owned, do you mind movin
Qiang(Joe) Xu 2016/08/01 22:56:47 Done.
+ TrayAudio* tray_audio_;
Daniel Erat 2016/08/01 21:10:06 nit: document that this may be null, e.g. TrayA
Qiang(Joe) Xu 2016/08/01 22:56:47 Done.
TrayCast* tray_cast_;
TrayDate* tray_date_;
TrayUpdate* tray_update_;

Powered by Google App Engine
This is Rietveld 408576698